package com.vendor.loader.views;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.model.devices.unknown.UnknownDevice;
import com.vendor.burn.utilitily.ToolUtils;
import com.vendor.loader.Log.Log;
import com.vendor.loader.Messages;
import com.vendor.loader.adapter.SOCTFileImg;
import com.vendor.loader.adapter.SOCTOTAImg;
import com.vendor.loader.adapter.SsuOTAImg;
import com.vendor.loader.controler.GlobleControler;
import com.vendor.loader.model.CommonAdapter;
import com.vendor.loader.model.config.SOCTConfig;
import com.vendor.loader.model.config.SSUConfig;
import com.vendor.loader.struct.UpgradeFileInfo;
import com.vendor.loader.struct.UpgradeInfo;
import com.vendor.loader.struct.ssu.SsuUpgradeInfo;
import com.vendor.loader.util.JarUtility;
import com.vendor.loader.util.PropertiesUtility;
import com.vendor.loader.util.ssu.SsuPackageOptions;
import java.io.File;
import java.util.ArrayList;

public class CmdMain {
  private static final String VERSION = "5.4.15";
  
  public static void main(String[] args) {
    if (args == null || args.length == 0) {
      help();
      return;
    } 
    PropertiesUtility.setCmdLine(true);
    ToolUtils.setCmdLine(true);
    CommonAdapter cmdLineParam = new CommonAdapter();
    com.vendor.loader.views.CmdMain cmdMain = new com.vendor.loader.views.CmdMain();
    if (!parseFirstParam(args, cmdLineParam, cmdMain)) {
      help();
      return;
    } 
  }
  
  private static boolean parseFirstParam(String[] args, CommonAdapter cmdLineParam, com.vendor.loader.views.CmdMain cmdMain) {
    String cmdType = args[0];
    if (cmdType == null)
      return false; 
    if (cmdMain.checkCmdType(cmdType, "--help", "-h")) {
      help();
    } else if (cmdMain.checkCmdType(cmdType, "--version", "-v")) {
      printVersion();
    } else if (cmdMain.checkCmdType(cmdType, "--soctota", "-o")) {
      if (!cmdMain.callCreateSOCTOTA(args, cmdLineParam))
        return false; 
    } else if (cmdMain.checkCmdType(cmdType, "--soctfile", "-f")) {
      if (!cmdMain.callCreateSOCTFile(args, cmdLineParam))
        return false; 
    } else if (cmdMain.checkCmdType(cmdType, "--ssuota", "-so")) {
      if (!cmdMain.callCreateSsuOTA(args, cmdLineParam))
        return false; 
    } else {
      return false;
    } 
    return true;
  }
  
  private boolean callCreateSOCTOTA(String[] args, CommonAdapter cmdLineParam) {
    int argsLen = args.length;
    String outputFilePath = cmdLineParam.parseFile(args, argsLen, CmdParamName.outputFile
        .name(), CmdParamName.outputFile
        .ordinal(), false);
    if (outputFilePath == null)
      return false; 
    String configFilePath = getDefaultConfigPath("soctota.config");
    if (argsLen > CmdParamName.configFile.ordinal()) {
      configFilePath = cmdLineParam.parseFile(args, argsLen, CmdParamName.configFile
          .name(), CmdParamName.configFile
          .ordinal(), true);
      if (configFilePath == null)
        return false; 
    } 
    SOCTConfig soctConfig = new SOCTConfig(configFilePath);
    if (!soctConfig.isLoadResult())
      return false; 
    String chipName = soctConfig.getChipName();
    UnknownDevice ud = new UnknownDevice(chipName);
    if (!ud.isValid()) {
      Log.errorln("Unsupported device. LoaderToolCLI will not work for this device.");
      return false;
    } 
    GlobleControler.setBranchByChipNameType(ud.getChipNameType());
    ArrayList<UpgradeFileInfo> updateFiles = soctConfig.getUpgradFiles();
    UpgradeInfo upgradeInfo = soctConfig.getUpgradeInfo();
    SOCTOTAImg soctOTAImage = new SOCTOTAImg();
    boolean result = soctOTAImage.callCreateSOCTOTA(outputFilePath, updateFiles, upgradeInfo);
    if (!result)
      return false; 
    return true;
  }
  
  private boolean callCreateSOCTFile(String[] args, CommonAdapter cmdLineParam) {
    int argsLen = args.length;
    String outputFilePath = cmdLineParam.parseFile(args, argsLen, CmdParamName.outputFile
        .name(), CmdParamName.outputFile
        .ordinal(), false);
    if (outputFilePath == null)
      return false; 
    String configFilePath = getDefaultConfigPath("soctfile.config");
    if (argsLen > CmdParamName.configFile.ordinal()) {
      configFilePath = cmdLineParam.parseFile(args, argsLen, CmdParamName.configFile
          .name(), CmdParamName.configFile
          .ordinal(), true);
      if (configFilePath == null)
        return false; 
    } 
    SOCTConfig soctConfig = new SOCTConfig(configFilePath);
    if (!soctConfig.isLoadResult())
      return false; 
    String chipName = soctConfig.getChipName();
    UnknownDevice ud = new UnknownDevice(chipName);
    if (!ud.isValid()) {
      Log.errorln("Unsupported device. LoaderToolCLI will not work for this device.");
      return false;
    } 
    GlobleControler.setBranchByChipNameType(ud.getChipNameType());
    ArrayList<UpgradeFileInfo> updateFiles = soctConfig.getUpgradFiles();
    UpgradeInfo upgradeInfo = soctConfig.getUpgradeInfo();
    SOCTFileImg sOCTFileImg = new SOCTFileImg();
    boolean result = sOCTFileImg.callCreateSOCTFile(outputFilePath, updateFiles, upgradeInfo);
    if (!result)
      return false; 
    return true;
  }
  
  private boolean callCreateSsuOTA(String[] args, CommonAdapter cmdLineParam) {
    int argsLen = args.length;
    String outputFilePath = cmdLineParam.parseFile(args, argsLen, CmdParamName.outputFile
        .name(), CmdParamName.outputFile
        .ordinal(), false);
    if (outputFilePath == null)
      return false; 
    String configFilePath = getDefaultConfigPath("ssuota.config");
    if (argsLen > CmdParamName.configFile.ordinal()) {
      configFilePath = cmdLineParam.parseFile(args, argsLen, CmdParamName.configFile
          .name(), CmdParamName.configFile
          .ordinal(), true);
      if (configFilePath == null)
        return false; 
    } 
    SSUConfig ssuConfig = new SSUConfig(configFilePath);
    if (!ssuConfig.isLoadResult())
      return false; 
    String chipName = ssuConfig.getChipName();
    UnknownDevice ud = new UnknownDevice(chipName);
    if (!ud.isValid()) {
      Log.errorln("Unsupported device. LoaderToolCLI will not work for this device.");
      return false;
    } 
    GlobleControler.setBranchByChipNameType(ud.getChipNameType());
    ArrayList<UpgradeFileInfo> updateFiles = ssuConfig.getUpdateFiles();
    SsuUpgradeInfo ssuUpgradeInfo = ssuConfig.getSsuUpgradeInfo();
    SsuPackageOptions ssuPackageOptions = ssuConfig.getSsuPackageOptions();
    SsuOTAImg ssuOTAImg = new SsuOTAImg();
    boolean result = ssuOTAImg.callCreateSsuOTA(outputFilePath, updateFiles, ssuUpgradeInfo, ssuPackageOptions);
    if (!result)
      return false; 
    return true;
  }
  
  private String getDefaultConfigPath(String configName) {
    StringBuilder sbuild = new StringBuilder();
    sbuild.append(JarUtility.getJarDir());
    sbuild.append(File.separator);
    sbuild.append("sample");
    sbuild.append(File.separator);
    sbuild.append("config");
    sbuild.append(File.separator);
    sbuild.append(configName);
    return sbuild.toString();
  }
  
  private boolean checkCmdType(String cmdType, String fullCmdName, String shortCmdName) {
    boolean result = (cmdType.equalsIgnoreCase(fullCmdName) || cmdType.equalsIgnoreCase(shortCmdName));
    return result;
  }
  
  private static void help() {
    Log.println("HiLoaderCmdLine.jar --soctota <outputFile> [configFile]");
    Log.println("This command creates a OTA upgrade stream for the SOCT protocolbased on the partition table xmlPath.");
    Log.println("");
    Log.println("HiLoaderCmdLine.jar --soctfile <outputFile> [configFile]");
    Log.println("This command creates a USB upgrade stream for the SOCT protocolbased on the partition table xmlPath.");
    Log.println("");
    Log.println("HiLoaderCmdLine.jar --ssuota <outputFile> [configFile]");
    Log.println("This command creates a OTA upgrade stream for the SSU protocolbased on the partition table xmlPath.");
    Log.println("");
    Log.println("general options:");
    Log.println("--help    | -h    usage message");
    Log.println("--version | -v    version number and copyright");
    Log.println("--soctota | -o    the command is used to create the OTA stream of SOCT protocol.");
    Log.println("--soctfile| -f    the command is used to create the FILE stream of SOCT protocol.");
    Log.println("--ssuota  | -so   the command is used to create the OTA stream of SSU protocol.");
  }
  
  private static void printVersion() {
    Log.println(Messages.MESSAGE_LOADER_VERSION_NAME + "5.4.15");
    Log.println(Messages.MESSAGE_LOADER_RESERVED);
  }
}
